package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Jan 14, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
Reset = "\033[0m"
Red = "\033[31m"
Green = "\033[32m"
Yellow = "\033[33m"
Blue = "\033[34m"
Magenta = "\033[35m"
Cyan = "\033[36m"
Gray = "\033[90m"
)
Colors for terminal output
func Error(format string, args ...interface{})
Error prints an error message
Header prints a section header
func Info(format string, args ...interface{})
Info prints an info message
func Status(name, status, detail string)
Status prints a status line
func Success(format string, args ...interface{})
Success prints a success message
func Warning(format string, args ...interface{})
Warning prints a warning message
Source Files
¶
Click to show internal directories.
Click to hide internal directories.